@@ -58,7 +58,7 @@ def get_http_host_ip() -> str:
     return urlsplit('//' + http_host).hostname
 
 
-def update_config(run_id: int, config_item_dict: dict):
+def update_config(run_id: int, config_item_dict: list):
     def makeItem(item):
         key, value = item
         if isinstance(value, int):
@@ -78,8 +78,9 @@ def update_config(run_id: int, config_item_dict: dict):
 
     # client 정보 추가
     import deepdriver.version as version
-    config_item_dict['cliVer'] = version.__version__
-    config_item_dict['pythonVer'] = util.get_python_version()
+    config_item_dict.append(('cliVer', version.__version__))
+    config_item_dict.append(('pythonVer', util.get_python_version()))
+
 
     item = map(makeItem, config_item_dict)
     rsp: UpdateConfigResponse = get_stub().update_config(UpdateConfigRequest(
